check_creation_permission

Function check_creation_permission 

pub async fn check_creation_permission(
    user_info: &UserInfo,
) -> Result<(), ServiceError>
Check if the current user has the correct permissions to create a map.

Errors

If the user does not have the required rights for creating a map.